scipy.sparse.bsr
================

.. automodule:: scipy.sparse.bsr

   
   
   .. rubric:: Functions

   .. autosummary::
   
      bsr_matmat_pass2
      bsr_matvec
      bsr_matvecs
      bsr_sort_indices
      bsr_transpose
      csr_matmat_pass1
      getdtype
      isshape
      isspmatrix
      isspmatrix_bsr
      to_native
      upcast
      warn
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      bsr_matrix
   
   

   
   
   